@@ -15,4 +15,11 @@ SLASH = 1
 USER = 2
 MESSAGE = 3
 
-__version__ = '1.0.4'
\ No newline at end of file
+# Set message response types
+CHANNEL_WITH_SOURCE = 4
+DEFERRED_CHANNEL_WITH_SOURCE = 5
+DEFERRED_UPDATE_MESSAGE = 6
+UPDATE_MESSAGE = 7
+AUTOCOMPLETE_RESULT = 8
+
+__version__ = '1.0.7'
\ No newline at end of file
